# overseerr-api
This is the documentation for the Overseerr API backend.

Two primary authentication methods are supported:

- **Cookie Authentication**: A valid sign-in to the `/auth/plex` or `/auth/local` will generate a valid authentication cookie.
- **API Key Authentication**: Sign-in is also possible by passing an `X-Api-Key` header along with a valid API Key generated by Overseerr.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/l-holter/overseerr-api.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/l-holter/overseerr-api.git`)

Then import the package:
```python
import overseerr_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import overseerr_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import overseerr_api
from overseerr_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:5055/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = overseerr_api.Configuration(
    host = "http://localhost:5055/api/v1"
)



# Enter a context with an instance of the API client
with overseerr_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = overseerr_api.AuthApi(api_client)
    auth_local_post_request = overseerr_api.AuthLocalPostRequest() # AuthLocalPostRequest | 

    try:
        # Sign in using a local account
        api_response = api_instance.auth_local_post(auth_local_post_request)
        print("The response of AuthApi->auth_local_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthApi->auth_local_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:5055/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**auth_local_post**](docs/AuthApi.md#auth_local_post) | **POST** /auth/local | Sign in using a local account
*AuthApi* | [**auth_logout_post**](docs/AuthApi.md#auth_logout_post) | **POST** /auth/logout | Sign out and clear session cookie
*AuthApi* | [**auth_me_get**](docs/AuthApi.md#auth_me_get) | **GET** /auth/me | Get logged-in user
*AuthApi* | [**auth_plex_post**](docs/AuthApi.md#auth_plex_post) | **POST** /auth/plex | Sign in using a Plex token
*CollectionApi* | [**collection_collection_id_get**](docs/CollectionApi.md#collection_collection_id_get) | **GET** /collection/{collectionId} | Get collection details
*IssueApi* | [**issue_comment_comment_id_delete**](docs/IssueApi.md#issue_comment_comment_id_delete) | **DELETE** /issueComment/{commentId} | Delete issue comment
*IssueApi* | [**issue_comment_comment_id_get**](docs/IssueApi.md#issue_comment_comment_id_get) | **GET** /issueComment/{commentId} | Get issue comment
*IssueApi* | [**issue_comment_comment_id_put**](docs/IssueApi.md#issue_comment_comment_id_put) | **PUT** /issueComment/{commentId} | Update issue comment
*IssueApi* | [**issue_count_get**](docs/IssueApi.md#issue_count_get) | **GET** /issue/count | Gets issue counts
*IssueApi* | [**issue_get**](docs/IssueApi.md#issue_get) | **GET** /issue | Get all issues
*IssueApi* | [**issue_issue_id_comment_post**](docs/IssueApi.md#issue_issue_id_comment_post) | **POST** /issue/{issueId}/comment | Create a comment
*IssueApi* | [**issue_issue_id_delete**](docs/IssueApi.md#issue_issue_id_delete) | **DELETE** /issue/{issueId} | Delete issue
*IssueApi* | [**issue_issue_id_get**](docs/IssueApi.md#issue_issue_id_get) | **GET** /issue/{issueId} | Get issue
*IssueApi* | [**issue_issue_id_status_post**](docs/IssueApi.md#issue_issue_id_status_post) | **POST** /issue/{issueId}/{status} | Update an issue&#39;s status
*IssueApi* | [**issue_post**](docs/IssueApi.md#issue_post) | **POST** /issue | Create new issue
*MediaApi* | [**media_get**](docs/MediaApi.md#media_get) | **GET** /media | Get media
*MediaApi* | [**media_media_id_delete**](docs/MediaApi.md#media_media_id_delete) | **DELETE** /media/{mediaId} | Delete media item
*MediaApi* | [**media_media_id_status_post**](docs/MediaApi.md#media_media_id_status_post) | **POST** /media/{mediaId}/{status} | Update media status
*MediaApi* | [**media_media_id_watch_data_get**](docs/MediaApi.md#media_media_id_watch_data_get) | **GET** /media/{mediaId}/watch_data | Get watch data
*MoviesApi* | [**movie_movie_id_get**](docs/MoviesApi.md#movie_movie_id_get) | **GET** /movie/{movieId} | Get movie details
*MoviesApi* | [**movie_movie_id_ratings_get**](docs/MoviesApi.md#movie_movie_id_ratings_get) | **GET** /movie/{movieId}/ratings | Get movie ratings
*MoviesApi* | [**movie_movie_id_ratingscombined_get**](docs/MoviesApi.md#movie_movie_id_ratingscombined_get) | **GET** /movie/{movieId}/ratingscombined | Get RT and IMDB movie ratings combined
*MoviesApi* | [**movie_movie_id_recommendations_get**](docs/MoviesApi.md#movie_movie_id_recommendations_get) | **GET** /movie/{movieId}/recommendations | Get recommended movies
*MoviesApi* | [**movie_movie_id_similar_get**](docs/MoviesApi.md#movie_movie_id_similar_get) | **GET** /movie/{movieId}/similar | Get similar movies
*OtherApi* | [**keyword_keyword_id_get**](docs/OtherApi.md#keyword_keyword_id_get) | **GET** /keyword/{keywordId} | Get keyword
*OtherApi* | [**watchproviders_movies_get**](docs/OtherApi.md#watchproviders_movies_get) | **GET** /watchproviders/movies | Get watch provider movies
*OtherApi* | [**watchproviders_regions_get**](docs/OtherApi.md#watchproviders_regions_get) | **GET** /watchproviders/regions | Get watch provider regions
*OtherApi* | [**watchproviders_tv_get**](docs/OtherApi.md#watchproviders_tv_get) | **GET** /watchproviders/tv | Get watch provider series
*PersonApi* | [**person_person_id_combined_credits_get**](docs/PersonApi.md#person_person_id_combined_credits_get) | **GET** /person/{personId}/combined_credits | Get combined credits
*PersonApi* | [**person_person_id_get**](docs/PersonApi.md#person_person_id_get) | **GET** /person/{personId} | Get person details
*PublicApi* | [**status_appdata_get**](docs/PublicApi.md#status_appdata_get) | **GET** /status/appdata | Get application data volume status
*PublicApi* | [**status_get**](docs/PublicApi.md#status_get) | **GET** /status | Get Overseerr status
*RequestApi* | [**request_count_get**](docs/RequestApi.md#request_count_get) | **GET** /request/count | Gets request counts
*RequestApi* | [**request_get**](docs/RequestApi.md#request_get) | **GET** /request | Get all requests
*RequestApi* | [**request_post**](docs/RequestApi.md#request_post) | **POST** /request | Create new request
*RequestApi* | [**request_request_id_delete**](docs/RequestApi.md#request_request_id_delete) | **DELETE** /request/{requestId} | Delete request
*RequestApi* | [**request_request_id_get**](docs/RequestApi.md#request_request_id_get) | **GET** /request/{requestId} | Get MediaRequest
*RequestApi* | [**request_request_id_put**](docs/RequestApi.md#request_request_id_put) | **PUT** /request/{requestId} | Update MediaRequest
*RequestApi* | [**request_request_id_retry_post**](docs/RequestApi.md#request_request_id_retry_post) | **POST** /request/{requestId}/retry | Retry failed request
*RequestApi* | [**request_request_id_status_post**](docs/RequestApi.md#request_request_id_status_post) | **POST** /request/{requestId}/{status} | Update a request&#39;s status
*SearchApi* | [**discover_genreslider_movie_get**](docs/SearchApi.md#discover_genreslider_movie_get) | **GET** /discover/genreslider/movie | Get genre slider data for movies
*SearchApi* | [**discover_genreslider_tv_get**](docs/SearchApi.md#discover_genreslider_tv_get) | **GET** /discover/genreslider/tv | Get genre slider data for TV series
*SearchApi* | [**discover_keyword_keyword_id_movies_get**](docs/SearchApi.md#discover_keyword_keyword_id_movies_get) | **GET** /discover/keyword/{keywordId}/movies | Get movies from keyword
*SearchApi* | [**discover_movies_genre_genre_id_get**](docs/SearchApi.md#discover_movies_genre_genre_id_get) | **GET** /discover/movies/genre/{genreId} | Discover movies by genre
*SearchApi* | [**discover_movies_get**](docs/SearchApi.md#discover_movies_get) | **GET** /discover/movies | Discover movies
*SearchApi* | [**discover_movies_language_language_get**](docs/SearchApi.md#discover_movies_language_language_get) | **GET** /discover/movies/language/{language} | Discover movies by original language
*SearchApi* | [**discover_movies_studio_studio_id_get**](docs/SearchApi.md#discover_movies_studio_studio_id_get) | **GET** /discover/movies/studio/{studioId} | Discover movies by studio
*SearchApi* | [**discover_movies_upcoming_get**](docs/SearchApi.md#discover_movies_upcoming_get) | **GET** /discover/movies/upcoming | Upcoming movies
*SearchApi* | [**discover_trending_get**](docs/SearchApi.md#discover_trending_get) | **GET** /discover/trending | Trending movies and TV
*SearchApi* | [**discover_tv_genre_genre_id_get**](docs/SearchApi.md#discover_tv_genre_genre_id_get) | **GET** /discover/tv/genre/{genreId} | Discover TV shows by genre
*SearchApi* | [**discover_tv_get**](docs/SearchApi.md#discover_tv_get) | **GET** /discover/tv | Discover TV shows
*SearchApi* | [**discover_tv_language_language_get**](docs/SearchApi.md#discover_tv_language_language_get) | **GET** /discover/tv/language/{language} | Discover TV shows by original language
*SearchApi* | [**discover_tv_network_network_id_get**](docs/SearchApi.md#discover_tv_network_network_id_get) | **GET** /discover/tv/network/{networkId} | Discover TV shows by network
*SearchApi* | [**discover_tv_upcoming_get**](docs/SearchApi.md#discover_tv_upcoming_get) | **GET** /discover/tv/upcoming | Discover Upcoming TV shows
*SearchApi* | [**discover_watchlist_get**](docs/SearchApi.md#discover_watchlist_get) | **GET** /discover/watchlist | Get the Plex watchlist.
*SearchApi* | [**search_company_get**](docs/SearchApi.md#search_company_get) | **GET** /search/company | Search for companies
*SearchApi* | [**search_get**](docs/SearchApi.md#search_get) | **GET** /search | Search for movies, TV shows, or people
*SearchApi* | [**search_keyword_get**](docs/SearchApi.md#search_keyword_get) | **GET** /search/keyword | Search for keywords
*ServiceApi* | [**service_radarr_get**](docs/ServiceApi.md#service_radarr_get) | **GET** /service/radarr | Get non-sensitive Radarr server list
*ServiceApi* | [**service_radarr_radarr_id_get**](docs/ServiceApi.md#service_radarr_radarr_id_get) | **GET** /service/radarr/{radarrId} | Get Radarr server quality profiles and root folders
*ServiceApi* | [**service_sonarr_get**](docs/ServiceApi.md#service_sonarr_get) | **GET** /service/sonarr | Get non-sensitive Sonarr server list
*ServiceApi* | [**service_sonarr_lookup_tmdb_id_get**](docs/ServiceApi.md#service_sonarr_lookup_tmdb_id_get) | **GET** /service/sonarr/lookup/{tmdbId} | Get series from Sonarr
*ServiceApi* | [**service_sonarr_sonarr_id_get**](docs/ServiceApi.md#service_sonarr_sonarr_id_get) | **GET** /service/sonarr/{sonarrId} | Get Sonarr server quality profiles and root folders
*SettingsApi* | [**settings_about_get**](docs/SettingsApi.md#settings_about_get) | **GET** /settings/about | Get server stats
*SettingsApi* | [**settings_cache_cache_id_flush_post**](docs/SettingsApi.md#settings_cache_cache_id_flush_post) | **POST** /settings/cache/{cacheId}/flush | Flush a specific cache
*SettingsApi* | [**settings_cache_get**](docs/SettingsApi.md#settings_cache_get) | **GET** /settings/cache | Get a list of active caches
*SettingsApi* | [**settings_discover_add_post**](docs/SettingsApi.md#settings_discover_add_post) | **POST** /settings/discover/add | Add a new slider
*SettingsApi* | [**settings_discover_get**](docs/SettingsApi.md#settings_discover_get) | **GET** /settings/discover | Get all discover sliders
*SettingsApi* | [**settings_discover_post**](docs/SettingsApi.md#settings_discover_post) | **POST** /settings/discover | Batch update all sliders.
*SettingsApi* | [**settings_discover_reset_get**](docs/SettingsApi.md#settings_discover_reset_get) | **GET** /settings/discover/reset | Reset all discover sliders
*SettingsApi* | [**settings_discover_slider_id_delete**](docs/SettingsApi.md#settings_discover_slider_id_delete) | **DELETE** /settings/discover/{sliderId} | Delete slider by ID
*SettingsApi* | [**settings_discover_slider_id_put**](docs/SettingsApi.md#settings_discover_slider_id_put) | **PUT** /settings/discover/{sliderId} | Update a single slider
*SettingsApi* | [**settings_initialize_post**](docs/SettingsApi.md#settings_initialize_post) | **POST** /settings/initialize | Initialize application
*SettingsApi* | [**settings_jobs_get**](docs/SettingsApi.md#settings_jobs_get) | **GET** /settings/jobs | Get scheduled jobs
*SettingsApi* | [**settings_jobs_job_id_cancel_post**](docs/SettingsApi.md#settings_jobs_job_id_cancel_post) | **POST** /settings/jobs/{jobId}/cancel | Cancel a specific job
*SettingsApi* | [**settings_jobs_job_id_run_post**](docs/SettingsApi.md#settings_jobs_job_id_run_post) | **POST** /settings/jobs/{jobId}/run | Invoke a specific job
*SettingsApi* | [**settings_jobs_job_id_schedule_post**](docs/SettingsApi.md#settings_jobs_job_id_schedule_post) | **POST** /settings/jobs/{jobId}/schedule | Modify job schedule
*SettingsApi* | [**settings_logs_get**](docs/SettingsApi.md#settings_logs_get) | **GET** /settings/logs | Returns logs
*SettingsApi* | [**settings_main_get**](docs/SettingsApi.md#settings_main_get) | **GET** /settings/main | Get main settings
*SettingsApi* | [**settings_main_post**](docs/SettingsApi.md#settings_main_post) | **POST** /settings/main | Update main settings
*SettingsApi* | [**settings_main_regenerate_post**](docs/SettingsApi.md#settings_main_regenerate_post) | **POST** /settings/main/regenerate | Get main settings with newly-generated API key
*SettingsApi* | [**settings_notifications_discord_get**](docs/SettingsApi.md#settings_notifications_discord_get) | **GET** /settings/notifications/discord | Get Discord notification settings
*SettingsApi* | [**settings_notifications_discord_post**](docs/SettingsApi.md#settings_notifications_discord_post) | **POST** /settings/notifications/discord | Update Discord notification settings
*SettingsApi* | [**settings_notifications_discord_test_post**](docs/SettingsApi.md#settings_notifications_discord_test_post) | **POST** /settings/notifications/discord/test | Test Discord settings
*SettingsApi* | [**settings_notifications_email_get**](docs/SettingsApi.md#settings_notifications_email_get) | **GET** /settings/notifications/email | Get email notification settings
*SettingsApi* | [**settings_notifications_email_post**](docs/SettingsApi.md#settings_notifications_email_post) | **POST** /settings/notifications/email | Update email notification settings
*SettingsApi* | [**settings_notifications_email_test_post**](docs/SettingsApi.md#settings_notifications_email_test_post) | **POST** /settings/notifications/email/test | Test email settings
*SettingsApi* | [**settings_notifications_gotify_get**](docs/SettingsApi.md#settings_notifications_gotify_get) | **GET** /settings/notifications/gotify | Get Gotify notification settings
*SettingsApi* | [**settings_notifications_gotify_post**](docs/SettingsApi.md#settings_notifications_gotify_post) | **POST** /settings/notifications/gotify | Update Gotify notification settings
*SettingsApi* | [**settings_notifications_gotify_test_post**](docs/SettingsApi.md#settings_notifications_gotify_test_post) | **POST** /settings/notifications/gotify/test | Test Gotify settings
*SettingsApi* | [**settings_notifications_lunasea_get**](docs/SettingsApi.md#settings_notifications_lunasea_get) | **GET** /settings/notifications/lunasea | Get LunaSea notification settings
*SettingsApi* | [**settings_notifications_lunasea_post**](docs/SettingsApi.md#settings_notifications_lunasea_post) | **POST** /settings/notifications/lunasea | Update LunaSea notification settings
*SettingsApi* | [**settings_notifications_lunasea_test_post**](docs/SettingsApi.md#settings_notifications_lunasea_test_post) | **POST** /settings/notifications/lunasea/test | Test LunaSea settings
*SettingsApi* | [**settings_notifications_pushbullet_get**](docs/SettingsApi.md#settings_notifications_pushbullet_get) | **GET** /settings/notifications/pushbullet | Get Pushbullet notification settings
*SettingsApi* | [**settings_notifications_pushbullet_post**](docs/SettingsApi.md#settings_notifications_pushbullet_post) | **POST** /settings/notifications/pushbullet | Update Pushbullet notification settings
*SettingsApi* | [**settings_notifications_pushbullet_test_post**](docs/SettingsApi.md#settings_notifications_pushbullet_test_post) | **POST** /settings/notifications/pushbullet/test | Test Pushbullet settings
*SettingsApi* | [**settings_notifications_pushover_get**](docs/SettingsApi.md#settings_notifications_pushover_get) | **GET** /settings/notifications/pushover | Get Pushover notification settings
*SettingsApi* | [**settings_notifications_pushover_post**](docs/SettingsApi.md#settings_notifications_pushover_post) | **POST** /settings/notifications/pushover | Update Pushover notification settings
*SettingsApi* | [**settings_notifications_pushover_sounds_get**](docs/SettingsApi.md#settings_notifications_pushover_sounds_get) | **GET** /settings/notifications/pushover/sounds | Get Pushover sounds
*SettingsApi* | [**settings_notifications_pushover_test_post**](docs/SettingsApi.md#settings_notifications_pushover_test_post) | **POST** /settings/notifications/pushover/test | Test Pushover settings
*SettingsApi* | [**settings_notifications_slack_get**](docs/SettingsApi.md#settings_notifications_slack_get) | **GET** /settings/notifications/slack | Get Slack notification settings
*SettingsApi* | [**settings_notifications_slack_post**](docs/SettingsApi.md#settings_notifications_slack_post) | **POST** /settings/notifications/slack | Update Slack notification settings
*SettingsApi* | [**settings_notifications_slack_test_post**](docs/SettingsApi.md#settings_notifications_slack_test_post) | **POST** /settings/notifications/slack/test | Test Slack settings
*SettingsApi* | [**settings_notifications_telegram_get**](docs/SettingsApi.md#settings_notifications_telegram_get) | **GET** /settings/notifications/telegram | Get Telegram notification settings
*SettingsApi* | [**settings_notifications_telegram_post**](docs/SettingsApi.md#settings_notifications_telegram_post) | **POST** /settings/notifications/telegram | Update Telegram notification settings
*SettingsApi* | [**settings_notifications_telegram_test_post**](docs/SettingsApi.md#settings_notifications_telegram_test_post) | **POST** /settings/notifications/telegram/test | Test Telegram settings
*SettingsApi* | [**settings_notifications_webhook_get**](docs/SettingsApi.md#settings_notifications_webhook_get) | **GET** /settings/notifications/webhook | Get webhook notification settings
*SettingsApi* | [**settings_notifications_webhook_post**](docs/SettingsApi.md#settings_notifications_webhook_post) | **POST** /settings/notifications/webhook | Update webhook notification settings
*SettingsApi* | [**settings_notifications_webhook_test_post**](docs/SettingsApi.md#settings_notifications_webhook_test_post) | **POST** /settings/notifications/webhook/test | Test webhook settings
*SettingsApi* | [**settings_notifications_webpush_get**](docs/SettingsApi.md#settings_notifications_webpush_get) | **GET** /settings/notifications/webpush | Get Web Push notification settings
*SettingsApi* | [**settings_notifications_webpush_post**](docs/SettingsApi.md#settings_notifications_webpush_post) | **POST** /settings/notifications/webpush | Update Web Push notification settings
*SettingsApi* | [**settings_notifications_webpush_test_post**](docs/SettingsApi.md#settings_notifications_webpush_test_post) | **POST** /settings/notifications/webpush/test | Test Web Push settings
*SettingsApi* | [**settings_plex_devices_servers_get**](docs/SettingsApi.md#settings_plex_devices_servers_get) | **GET** /settings/plex/devices/servers | Gets the user&#39;s available Plex servers
*SettingsApi* | [**settings_plex_get**](docs/SettingsApi.md#settings_plex_get) | **GET** /settings/plex | Get Plex settings
*SettingsApi* | [**settings_plex_library_get**](docs/SettingsApi.md#settings_plex_library_get) | **GET** /settings/plex/library | Get Plex libraries
*SettingsApi* | [**settings_plex_post**](docs/SettingsApi.md#settings_plex_post) | **POST** /settings/plex | Update Plex settings
*SettingsApi* | [**settings_plex_sync_get**](docs/SettingsApi.md#settings_plex_sync_get) | **GET** /settings/plex/sync | Get status of full Plex library scan
*SettingsApi* | [**settings_plex_sync_post**](docs/SettingsApi.md#settings_plex_sync_post) | **POST** /settings/plex/sync | Start full Plex library scan
*SettingsApi* | [**settings_plex_users_get**](docs/SettingsApi.md#settings_plex_users_get) | **GET** /settings/plex/users | Get Plex users
*SettingsApi* | [**settings_public_get**](docs/SettingsApi.md#settings_public_get) | **GET** /settings/public | Get public settings
*SettingsApi* | [**settings_radarr_get**](docs/SettingsApi.md#settings_radarr_get) | **GET** /settings/radarr | Get Radarr settings
*SettingsApi* | [**settings_radarr_post**](docs/SettingsApi.md#settings_radarr_post) | **POST** /settings/radarr | Create Radarr instance
*SettingsApi* | [**settings_radarr_radarr_id_delete**](docs/SettingsApi.md#settings_radarr_radarr_id_delete) | **DELETE** /settings/radarr/{radarrId} | Delete Radarr instance
*SettingsApi* | [**settings_radarr_radarr_id_profiles_get**](docs/SettingsApi.md#settings_radarr_radarr_id_profiles_get) | **GET** /settings/radarr/{radarrId}/profiles | Get available Radarr profiles
*SettingsApi* | [**settings_radarr_radarr_id_put**](docs/SettingsApi.md#settings_radarr_radarr_id_put) | **PUT** /settings/radarr/{radarrId} | Update Radarr instance
*SettingsApi* | [**settings_radarr_test_post**](docs/SettingsApi.md#settings_radarr_test_post) | **POST** /settings/radarr/test | Test Radarr configuration
*SettingsApi* | [**settings_sonarr_get**](docs/SettingsApi.md#settings_sonarr_get) | **GET** /settings/sonarr | Get Sonarr settings
*SettingsApi* | [**settings_sonarr_post**](docs/SettingsApi.md#settings_sonarr_post) | **POST** /settings/sonarr | Create Sonarr instance
*SettingsApi* | [**settings_sonarr_sonarr_id_delete**](docs/SettingsApi.md#settings_sonarr_sonarr_id_delete) | **DELETE** /settings/sonarr/{sonarrId} | Delete Sonarr instance
*SettingsApi* | [**settings_sonarr_sonarr_id_put**](docs/SettingsApi.md#settings_sonarr_sonarr_id_put) | **PUT** /settings/sonarr/{sonarrId} | Update Sonarr instance
*SettingsApi* | [**settings_sonarr_test_post**](docs/SettingsApi.md#settings_sonarr_test_post) | **POST** /settings/sonarr/test | Test Sonarr configuration
*SettingsApi* | [**settings_tautulli_get**](docs/SettingsApi.md#settings_tautulli_get) | **GET** /settings/tautulli | Get Tautulli settings
*SettingsApi* | [**settings_tautulli_post**](docs/SettingsApi.md#settings_tautulli_post) | **POST** /settings/tautulli | Update Tautulli settings
*TmdbApi* | [**backdrops_get**](docs/TmdbApi.md#backdrops_get) | **GET** /backdrops | Get backdrops of trending items
*TmdbApi* | [**genres_movie_get**](docs/TmdbApi.md#genres_movie_get) | **GET** /genres/movie | Get list of official TMDB movie genres
*TmdbApi* | [**genres_tv_get**](docs/TmdbApi.md#genres_tv_get) | **GET** /genres/tv | Get list of official TMDB movie genres
*TmdbApi* | [**languages_get**](docs/TmdbApi.md#languages_get) | **GET** /languages | Languages supported by TMDB
*TmdbApi* | [**network_network_id_get**](docs/TmdbApi.md#network_network_id_get) | **GET** /network/{networkId} | Get TV network details
*TmdbApi* | [**regions_get**](docs/TmdbApi.md#regions_get) | **GET** /regions | Regions supported by TMDB
*TmdbApi* | [**studio_studio_id_get**](docs/TmdbApi.md#studio_studio_id_get) | **GET** /studio/{studioId} | Get movie studio details
*TvApi* | [**tv_tv_id_get**](docs/TvApi.md#tv_tv_id_get) | **GET** /tv/{tvId} | Get TV details
*TvApi* | [**tv_tv_id_ratings_get**](docs/TvApi.md#tv_tv_id_ratings_get) | **GET** /tv/{tvId}/ratings | Get TV ratings
*TvApi* | [**tv_tv_id_recommendations_get**](docs/TvApi.md#tv_tv_id_recommendations_get) | **GET** /tv/{tvId}/recommendations | Get recommended TV series
*TvApi* | [**tv_tv_id_season_season_id_get**](docs/TvApi.md#tv_tv_id_season_season_id_get) | **GET** /tv/{tvId}/season/{seasonId} | Get season details and episode list
*TvApi* | [**tv_tv_id_similar_get**](docs/TvApi.md#tv_tv_id_similar_get) | **GET** /tv/{tvId}/similar | Get similar TV series
*UsersApi* | [**auth_me_get**](docs/UsersApi.md#auth_me_get) | **GET** /auth/me | Get logged-in user
*UsersApi* | [**auth_reset_password_guid_post**](docs/UsersApi.md#auth_reset_password_guid_post) | **POST** /auth/reset-password/{guid} | Reset the password for a user
*UsersApi* | [**auth_reset_password_post**](docs/UsersApi.md#auth_reset_password_post) | **POST** /auth/reset-password | Send a reset password email
*UsersApi* | [**settings_plex_users_get**](docs/UsersApi.md#settings_plex_users_get) | **GET** /settings/plex/users | Get Plex users
*UsersApi* | [**user_get**](docs/UsersApi.md#user_get) | **GET** /user | Get all users
*UsersApi* | [**user_import_from_plex_post**](docs/UsersApi.md#user_import_from_plex_post) | **POST** /user/import-from-plex | Import all users from Plex
*UsersApi* | [**user_post**](docs/UsersApi.md#user_post) | **POST** /user | Create new user
*UsersApi* | [**user_put**](docs/UsersApi.md#user_put) | **PUT** /user | Update batch of users
*UsersApi* | [**user_register_push_subscription_post**](docs/UsersApi.md#user_register_push_subscription_post) | **POST** /user/registerPushSubscription | Register a web push /user/registerPushSubscription
*UsersApi* | [**user_user_id_delete**](docs/UsersApi.md#user_user_id_delete) | **DELETE** /user/{userId} | Delete user by ID
*UsersApi* | [**user_user_id_get**](docs/UsersApi.md#user_user_id_get) | **GET** /user/{userId} | Get user by ID
*UsersApi* | [**user_user_id_put**](docs/UsersApi.md#user_user_id_put) | **PUT** /user/{userId} | Update a user by user ID
*UsersApi* | [**user_user_id_quota_get**](docs/UsersApi.md#user_user_id_quota_get) | **GET** /user/{userId}/quota | Get quotas for a specific user
*UsersApi* | [**user_user_id_requests_get**](docs/UsersApi.md#user_user_id_requests_get) | **GET** /user/{userId}/requests | Get requests for a specific user
*UsersApi* | [**user_user_id_settings_main_get**](docs/UsersApi.md#user_user_id_settings_main_get) | **GET** /user/{userId}/settings/main | Get general settings for a user
*UsersApi* | [**user_user_id_settings_main_post**](docs/UsersApi.md#user_user_id_settings_main_post) | **POST** /user/{userId}/settings/main | Update general settings for a user
*UsersApi* | [**user_user_id_settings_notifications_get**](docs/UsersApi.md#user_user_id_settings_notifications_get) | **GET** /user/{userId}/settings/notifications | Get notification settings for a user
*UsersApi* | [**user_user_id_settings_notifications_post**](docs/UsersApi.md#user_user_id_settings_notifications_post) | **POST** /user/{userId}/settings/notifications | Update notification settings for a user
*UsersApi* | [**user_user_id_settings_password_get**](docs/UsersApi.md#user_user_id_settings_password_get) | **GET** /user/{userId}/settings/password | Get password page informatiom
*UsersApi* | [**user_user_id_settings_password_post**](docs/UsersApi.md#user_user_id_settings_password_post) | **POST** /user/{userId}/settings/password | Update password for a user
*UsersApi* | [**user_user_id_settings_permissions_get**](docs/UsersApi.md#user_user_id_settings_permissions_get) | **GET** /user/{userId}/settings/permissions | Get permission settings for a user
*UsersApi* | [**user_user_id_settings_permissions_post**](docs/UsersApi.md#user_user_id_settings_permissions_post) | **POST** /user/{userId}/settings/permissions | Update permission settings for a user
*UsersApi* | [**user_user_id_watch_data_get**](docs/UsersApi.md#user_user_id_watch_data_get) | **GET** /user/{userId}/watch_data | Get watch data
*UsersApi* | [**user_user_id_watchlist_get**](docs/UsersApi.md#user_user_id_watchlist_get) | **GET** /user/{userId}/watchlist | Get the Plex watchlist for a specific user


## Documentation For Models

 - [AuthLocalPostRequest](docs/AuthLocalPostRequest.md)
 - [AuthLogoutPost200Response](docs/AuthLogoutPost200Response.md)
 - [AuthPlexPostRequest](docs/AuthPlexPostRequest.md)
 - [AuthResetPasswordGuidPostRequest](docs/AuthResetPasswordGuidPostRequest.md)
 - [AuthResetPasswordPostRequest](docs/AuthResetPasswordPostRequest.md)
 - [Cast](docs/Cast.md)
 - [Collection](docs/Collection.md)
 - [Company](docs/Company.md)
 - [CreditCast](docs/CreditCast.md)
 - [CreditCrew](docs/CreditCrew.md)
 - [Crew](docs/Crew.md)
 - [DiscordSettings](docs/DiscordSettings.md)
 - [DiscordSettingsOptions](docs/DiscordSettingsOptions.md)
 - [DiscoverGenresliderMovieGet200ResponseInner](docs/DiscoverGenresliderMovieGet200ResponseInner.md)
 - [DiscoverKeywordKeywordIdMoviesGet200Response](docs/DiscoverKeywordKeywordIdMoviesGet200Response.md)
 - [DiscoverMoviesGenreGenreIdGet200Response](docs/DiscoverMoviesGenreGenreIdGet200Response.md)
 - [DiscoverMoviesLanguageLanguageGet200Response](docs/DiscoverMoviesLanguageLanguageGet200Response.md)
 - [DiscoverMoviesStudioStudioIdGet200Response](docs/DiscoverMoviesStudioStudioIdGet200Response.md)
 - [DiscoverSlider](docs/DiscoverSlider.md)
 - [DiscoverTrendingGet200Response](docs/DiscoverTrendingGet200Response.md)
 - [DiscoverTrendingGet200ResponseResultsInner](docs/DiscoverTrendingGet200ResponseResultsInner.md)
 - [DiscoverTvGenreGenreIdGet200Response](docs/DiscoverTvGenreGenreIdGet200Response.md)
 - [DiscoverTvGet200Response](docs/DiscoverTvGet200Response.md)
 - [DiscoverTvLanguageLanguageGet200Response](docs/DiscoverTvLanguageLanguageGet200Response.md)
 - [DiscoverTvNetworkNetworkIdGet200Response](docs/DiscoverTvNetworkNetworkIdGet200Response.md)
 - [DiscoverWatchlistGet200Response](docs/DiscoverWatchlistGet200Response.md)
 - [DiscoverWatchlistGet200ResponseResultsInner](docs/DiscoverWatchlistGet200ResponseResultsInner.md)
 - [Episode](docs/Episode.md)
 - [ExternalIds](docs/ExternalIds.md)
 - [Genre](docs/Genre.md)
 - [GenresMovieGet200ResponseInner](docs/GenresMovieGet200ResponseInner.md)
 - [GenresTvGet200ResponseInner](docs/GenresTvGet200ResponseInner.md)
 - [GotifySettings](docs/GotifySettings.md)
 - [GotifySettingsOptions](docs/GotifySettingsOptions.md)
 - [Issue](docs/Issue.md)
 - [IssueComment](docs/IssueComment.md)
 - [IssueCommentCommentIdPutRequest](docs/IssueCommentCommentIdPutRequest.md)
 - [IssueCountGet200Response](docs/IssueCountGet200Response.md)
 - [IssueGet200Response](docs/IssueGet200Response.md)
 - [IssueIssueIdCommentPostRequest](docs/IssueIssueIdCommentPostRequest.md)
 - [IssuePostRequest](docs/IssuePostRequest.md)
 - [Job](docs/Job.md)
 - [Keyword](docs/Keyword.md)
 - [LanguagesGet200ResponseInner](docs/LanguagesGet200ResponseInner.md)
 - [LunaSeaSettings](docs/LunaSeaSettings.md)
 - [LunaSeaSettingsOptions](docs/LunaSeaSettingsOptions.md)
 - [MainSettings](docs/MainSettings.md)
 - [MediaGet200Response](docs/MediaGet200Response.md)
 - [MediaInfo](docs/MediaInfo.md)
 - [MediaMediaIdStatusPostRequest](docs/MediaMediaIdStatusPostRequest.md)
 - [MediaMediaIdWatchDataGet200Response](docs/MediaMediaIdWatchDataGet200Response.md)
 - [MediaMediaIdWatchDataGet200ResponseData](docs/MediaMediaIdWatchDataGet200ResponseData.md)
 - [MediaRequest](docs/MediaRequest.md)
 - [MediaRequestModifiedBy](docs/MediaRequestModifiedBy.md)
 - [MovieDetails](docs/MovieDetails.md)
 - [MovieDetailsCollection](docs/MovieDetailsCollection.md)
 - [MovieDetailsCredits](docs/MovieDetailsCredits.md)
 - [MovieDetailsProductionCountriesInner](docs/MovieDetailsProductionCountriesInner.md)
 - [MovieDetailsReleases](docs/MovieDetailsReleases.md)
 - [MovieDetailsReleasesResultsInner](docs/MovieDetailsReleasesResultsInner.md)
 - [MovieDetailsReleasesResultsInnerReleaseDatesInner](docs/MovieDetailsReleasesResultsInnerReleaseDatesInner.md)
 - [MovieMovieIdRatingsGet200Response](docs/MovieMovieIdRatingsGet200Response.md)
 - [MovieMovieIdRatingscombinedGet200Response](docs/MovieMovieIdRatingscombinedGet200Response.md)
 - [MovieMovieIdRatingscombinedGet200ResponseImdb](docs/MovieMovieIdRatingscombinedGet200ResponseImdb.md)
 - [MovieResult](docs/MovieResult.md)
 - [Network](docs/Network.md)
 - [NotificationAgentTypes](docs/NotificationAgentTypes.md)
 - [NotificationEmailSettings](docs/NotificationEmailSettings.md)
 - [NotificationEmailSettingsOptions](docs/NotificationEmailSettingsOptions.md)
 - [PageInfo](docs/PageInfo.md)
 - [PersonDetails](docs/PersonDetails.md)
 - [PersonPersonIdCombinedCreditsGet200Response](docs/PersonPersonIdCombinedCreditsGet200Response.md)
 - [PersonResult](docs/PersonResult.md)
 - [PersonResultKnownForInner](docs/PersonResultKnownForInner.md)
 - [PlexConnection](docs/PlexConnection.md)
 - [PlexDevice](docs/PlexDevice.md)
 - [PlexLibrary](docs/PlexLibrary.md)
 - [PlexSettings](docs/PlexSettings.md)
 - [ProductionCompany](docs/ProductionCompany.md)
 - [PublicSettings](docs/PublicSettings.md)
 - [PushbulletSettings](docs/PushbulletSettings.md)
 - [PushbulletSettingsOptions](docs/PushbulletSettingsOptions.md)
 - [PushoverSettings](docs/PushoverSettings.md)
 - [PushoverSettingsOptions](docs/PushoverSettingsOptions.md)
 - [RadarrSettings](docs/RadarrSettings.md)
 - [RegionsGet200ResponseInner](docs/RegionsGet200ResponseInner.md)
 - [RelatedVideo](docs/RelatedVideo.md)
 - [RequestCountGet200Response](docs/RequestCountGet200Response.md)
 - [RequestGet200Response](docs/RequestGet200Response.md)
 - [RequestPostRequest](docs/RequestPostRequest.md)
 - [RequestPostRequestSeasons](docs/RequestPostRequestSeasons.md)
 - [RequestRequestIdPutRequest](docs/RequestRequestIdPutRequest.md)
 - [SearchCompanyGet200Response](docs/SearchCompanyGet200Response.md)
 - [SearchKeywordGet200Response](docs/SearchKeywordGet200Response.md)
 - [Season](docs/Season.md)
 - [ServarrTag](docs/ServarrTag.md)
 - [ServiceProfile](docs/ServiceProfile.md)
 - [ServiceRadarrRadarrIdGet200Response](docs/ServiceRadarrRadarrIdGet200Response.md)
 - [ServiceSonarrSonarrIdGet200Response](docs/ServiceSonarrSonarrIdGet200Response.md)
 - [SettingsAboutGet200Response](docs/SettingsAboutGet200Response.md)
 - [SettingsCacheGet200Response](docs/SettingsCacheGet200Response.md)
 - [SettingsCacheGet200ResponseApiCachesInner](docs/SettingsCacheGet200ResponseApiCachesInner.md)
 - [SettingsCacheGet200ResponseApiCachesInnerStats](docs/SettingsCacheGet200ResponseApiCachesInnerStats.md)
 - [SettingsCacheGet200ResponseImageCache](docs/SettingsCacheGet200ResponseImageCache.md)
 - [SettingsCacheGet200ResponseImageCacheTmdb](docs/SettingsCacheGet200ResponseImageCacheTmdb.md)
 - [SettingsDiscoverAddPostRequest](docs/SettingsDiscoverAddPostRequest.md)
 - [SettingsDiscoverSliderIdPutRequest](docs/SettingsDiscoverSliderIdPutRequest.md)
 - [SettingsJobsJobIdSchedulePostRequest](docs/SettingsJobsJobIdSchedulePostRequest.md)
 - [SettingsLogsGet200ResponseInner](docs/SettingsLogsGet200ResponseInner.md)
 - [SettingsNotificationsPushoverSoundsGet200ResponseInner](docs/SettingsNotificationsPushoverSoundsGet200ResponseInner.md)
 - [SettingsPlexSyncGet200Response](docs/SettingsPlexSyncGet200Response.md)
 - [SettingsPlexSyncPostRequest](docs/SettingsPlexSyncPostRequest.md)
 - [SettingsPlexUsersGet200ResponseInner](docs/SettingsPlexUsersGet200ResponseInner.md)
 - [SettingsRadarrTestPost200Response](docs/SettingsRadarrTestPost200Response.md)
 - [SettingsRadarrTestPostRequest](docs/SettingsRadarrTestPostRequest.md)
 - [SettingsSonarrTestPostRequest](docs/SettingsSonarrTestPostRequest.md)
 - [SlackSettings](docs/SlackSettings.md)
 - [SlackSettingsOptions](docs/SlackSettingsOptions.md)
 - [SonarrSeries](docs/SonarrSeries.md)
 - [SonarrSeriesAddOptionsInner](docs/SonarrSeriesAddOptionsInner.md)
 - [SonarrSeriesImagesInner](docs/SonarrSeriesImagesInner.md)
 - [SonarrSeriesRatingsInner](docs/SonarrSeriesRatingsInner.md)
 - [SonarrSeriesSeasonsInner](docs/SonarrSeriesSeasonsInner.md)
 - [SonarrSettings](docs/SonarrSettings.md)
 - [SpokenLanguage](docs/SpokenLanguage.md)
 - [StatusAppdataGet200Response](docs/StatusAppdataGet200Response.md)
 - [StatusGet200Response](docs/StatusGet200Response.md)
 - [TautulliSettings](docs/TautulliSettings.md)
 - [TelegramSettings](docs/TelegramSettings.md)
 - [TelegramSettingsOptions](docs/TelegramSettingsOptions.md)
 - [TvDetails](docs/TvDetails.md)
 - [TvDetailsContentRatings](docs/TvDetailsContentRatings.md)
 - [TvDetailsContentRatingsResultsInner](docs/TvDetailsContentRatingsResultsInner.md)
 - [TvDetailsCreatedByInner](docs/TvDetailsCreatedByInner.md)
 - [TvResult](docs/TvResult.md)
 - [TvTvIdRatingsGet200Response](docs/TvTvIdRatingsGet200Response.md)
 - [User](docs/User.md)
 - [UserGet200Response](docs/UserGet200Response.md)
 - [UserImportFromPlexPostRequest](docs/UserImportFromPlexPostRequest.md)
 - [UserPostRequest](docs/UserPostRequest.md)
 - [UserPutRequest](docs/UserPutRequest.md)
 - [UserRegisterPushSubscriptionPostRequest](docs/UserRegisterPushSubscriptionPostRequest.md)
 - [UserSettings](docs/UserSettings.md)
 - [UserSettingsNotifications](docs/UserSettingsNotifications.md)
 - [UserUserIdQuotaGet200Response](docs/UserUserIdQuotaGet200Response.md)
 - [UserUserIdQuotaGet200ResponseMovie](docs/UserUserIdQuotaGet200ResponseMovie.md)
 - [UserUserIdSettingsMainGet200Response](docs/UserUserIdSettingsMainGet200Response.md)
 - [UserUserIdSettingsMainPostRequest](docs/UserUserIdSettingsMainPostRequest.md)
 - [UserUserIdSettingsPasswordGet200Response](docs/UserUserIdSettingsPasswordGet200Response.md)
 - [UserUserIdSettingsPasswordPostRequest](docs/UserUserIdSettingsPasswordPostRequest.md)
 - [UserUserIdSettingsPermissionsGet200Response](docs/UserUserIdSettingsPermissionsGet200Response.md)
 - [UserUserIdSettingsPermissionsPostRequest](docs/UserUserIdSettingsPermissionsPostRequest.md)
 - [UserUserIdWatchDataGet200Response](docs/UserUserIdWatchDataGet200Response.md)
 - [WatchProviderDetails](docs/WatchProviderDetails.md)
 - [WatchProviderRegion](docs/WatchProviderRegion.md)
 - [WatchProvidersInner](docs/WatchProvidersInner.md)
 - [WebPushSettings](docs/WebPushSettings.md)
 - [WebhookSettings](docs/WebhookSettings.md)
 - [WebhookSettingsOptions](docs/WebhookSettingsOptions.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="apiKey"></a>
### apiKey

- **Type**: API key
- **API key parameter name**: X-Api-Key
- **Location**: HTTP header

<a id="cookieAuth"></a>
### cookieAuth

- **Type**: API key
- **API key parameter name**: connect.sid
- **Location**: 


## Author




